==> galaxeus_lib-0.0.56.tar.gz: lib/crypto/crypto.dart <==
import 'dart:convert';
import 'dart:typed_data';

import 'package:encrypt/encrypt.dart';

class Crypto {
  late String defaultKey;
  Crypto({
    required String key,
  }) {
    defaultKey = key;
  }

  String encryptMapToBase64({
    required Map data,
  }) {
    return encryptToBase64(text: json.encode(data));
  }

  String encryptListToBase64({
    required List data,
  }) {
    return encryptToBase64(text: json.encode(data));
  }

  Uint8List encryptBytes({
    required List<int> data,
    String? key,
  }) {
    key ??= defaultKey;
    final encrypter = Encrypter(AES(Key.fromUtf8(key)));
    return encrypter.encryptBytes(data, iv: IV.fromLength(16)).bytes;
  }

  List<int> decryptBytes({
    required List<int> data,
    String? key,
  }) {
    key ??= defaultKey;
    final encrypter = Encrypter(AES(Key.fromUtf8(key)));
    return encrypter.decryptBytes(Encrypted(Uint8List.fromList(data)), iv: IV.fromLength(16));
  }

  Uint8List encryptsBytes({
    required List<int> data,
    required List<String> keys,
  }) {
    Uint8List uint8list = Uint8List.fromList(data);
    for (var i = 0; i < keys.length; i++) {
      String key = keys[i];
      uint8list = (encryptBytes(data: uint8list, key: key));
    }
    return uint8list;
  }

  List<int> decryptsBytes({
    required List<int> data,
    required List<String> keys,
  }) {
    List<int> uint8list = data;
    for (var i = keys.length - 1; i > -1; i--) {
      String key = keys[i];
      uint8list = (decryptBytes(data: uint8list, key: key));
    }
    return uint8list;
  }

  String encryptToBase64({
    required String text,
    String? key,
  }) {
    key ??= defaultKey;
    final encrypter = Encrypter(AES(Key.fromUtf8(key)));

    return encrypter.encrypt(text, iv: IV.fromLength(16)).base64;
  }

  String decryptFromBase64({
    required String text,
    String? key,
  }) {
    key ??= defaultKey;
    final encrypter = Encrypter(AES(Key.fromUtf8(key)));
    return encrypter.decrypt64(text, iv: IV.fromLength(16));
  }
 
}

==> galaxeus_lib-0.0.69.tar.gz: lib/crypto/crypto.dart <==
import 'dart:convert';
import 'dart:typed_data';

import 'package:encrypt/encrypt.dart';

class Crypto {
  late String defaultKey;
  Crypto({
    required String key,
  }) {
    defaultKey = key;
  }

  String encryptMapToBase64({
    required Map data,
  }) {
    return encryptToBase64(text: json.encode(data));
  }

  String encryptListToBase64({
    required List data,
  }) {
    return encryptToBase64(text: json.encode(data));
  }

  Uint8List encryptBytes({
    required List<int> data,
    String? key,
  }) {
    key ??= defaultKey;
    final encrypter = Encrypter(AES(Key.fromUtf8(key)));
    return encrypter.encryptBytes(data, iv: IV.fromLength(16)).bytes;
  }

  List<int> decryptBytes({
    required List<int> data,
    String? key,
  }) {
    key ??= defaultKey;
    final encrypter = Encrypter(AES(Key.fromUtf8(key)));
    return encrypter.decryptBytes(Encrypted(Uint8List.fromList(data)),
        iv: IV.fromLength(16));
  }

  Uint8List encryptsBytes({
    required List<int> data,
    required List<String> keys,
  }) {
    Uint8List uint8list = Uint8List.fromList(data);
    for (var i = 0; i < keys.length; i++) {
      String key = keys[i];
      uint8list = (encryptBytes(data: uint8list, key: key));
    }
    return uint8list;
  }

  List<int> decryptsBytes({
    required List<int> data,
    required List<String> keys,
  }) {
    List<int> uint8list = data;
    for (var i = keys.length - 1; i > -1; i--) {
      String key = keys[i];
      uint8list = (decryptBytes(data: uint8list, key: key));
    }
    return uint8list;
  }

  String encryptToBase64({
    required String text,
    String? key,
  }) {
    key ??= defaultKey;
    final encrypter = Encrypter(AES(Key.fromUtf8(key)));

    return encrypter.encrypt(text, iv: IV.fromLength(16)).base64;
  }

  String decryptFromBase64({
    required String text,
    String? key,
  }) {
    key ??= defaultKey;
    final encrypter = Encrypter(AES(Key.fromUtf8(key)));
    return encrypter.decrypt64(text, iv: IV.fromLength(16));
  }
}
